==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/openenergyplatform/kotlin/inputs/EnergyServicePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.openenergyplatform.kotlin.inputs

import com.pulumi.azurenative.openenergyplatform.inputs.EnergyServicePropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property authAppId
 * @property dataPartitionNames
 */
public data class EnergyServicePropertiesArgs(
    public val authAppId: Output<String>? = null,
    public val dataPartitionNames: Output<List<DataPartitionNamesArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.openenergyplatform.inputs.EnergyServicePropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.openenergyplatform.inputs.EnergyServicePropertiesArgs =
        com.pulumi.azurenative.openenergyplatform.inputs.EnergyServicePropertiesArgs.builder()
            .authAppId(authAppId?.applyValue({ args0 -> args0 }))
            .dataPartitionNames(
                dataPartitionNames?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [EnergyServicePropertiesArgs].
 */
@PulumiTagMarker
public class EnergyServicePropertiesArgsBuilder internal constructor() {
    private var authAppId: Output<String>? = null

    private var dataPartitionNames: Output<List<DataPartitionNamesArgs>>? = null

    /**
     * @param value
     */
    @JvmName("dkauhgpunpehqnyd")
    public suspend fun authAppId(`value`: Output<String>) {
        this.authAppId = value
    }

    /**
     * @param value
     */
    @JvmName("qgrjnifxdfumvabh")
    public suspend fun dataPartitionNames(`value`: Output<List<DataPartitionNamesArgs>>) {
        this.dataPartitionNames = value
    }

    @JvmName("xhdfpsteacmugiad")
    public suspend fun dataPartitionNames(vararg values: Output<DataPartitionNamesArgs>) {
        this.dataPartitionNames = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("gsbmondpsrbamqbn")
    public suspend fun dataPartitionNames(values: List<Output<DataPartitionNamesArgs>>) {
        this.dataPartitionNames = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("bxlqushtystuntxv")
    public suspend fun authAppId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authAppId = mapped
    }

    /**
     * @param value
     */
    @JvmName("oighmorqujvxyltq")
    public suspend fun dataPartitionNames(`value`: List<DataPartitionNamesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataPartitionNames = mapped
    }

    /**
     * @param argument
     */
    @JvmName("abycqresdhwwffmt")
    public suspend
    fun dataPartitionNames(argument: List<suspend DataPartitionNamesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataPartitionNamesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataPartitionNames = mapped
    }

    /**
     * @param argument
     */
    @JvmName("trmliagveerawbpw")
    public suspend fun dataPartitionNames(
        vararg
        argument: suspend DataPartitionNamesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            DataPartitionNamesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataPartitionNames = mapped
    }

    /**
     * @param argument
     */
    @JvmName("rrfahasywmqeydes")
    public suspend
    fun dataPartitionNames(argument: suspend DataPartitionNamesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataPartitionNamesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dataPartitionNames = mapped
    }

    /**
     * @param values
     */
    @JvmName("kqqtccdwvyftamio")
    public suspend fun dataPartitionNames(vararg values: DataPartitionNamesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataPartitionNames = mapped
    }

    internal fun build(): EnergyServicePropertiesArgs = EnergyServicePropertiesArgs(
        authAppId = authAppId,
        dataPartitionNames = dataPartitionNames,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/openenergyplatform/kotlin/inputs/EnergyServicePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.openenergyplatform.kotlin.inputs

import com.pulumi.azurenative.openenergyplatform.inputs.EnergyServicePropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property authAppId
 * @property dataPartitionNames
 */
public data class EnergyServicePropertiesArgs(
    public val authAppId: Output<String>? = null,
    public val dataPartitionNames: Output<List<DataPartitionNamesArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.openenergyplatform.inputs.EnergyServicePropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.openenergyplatform.inputs.EnergyServicePropertiesArgs =
        com.pulumi.azurenative.openenergyplatform.inputs.EnergyServicePropertiesArgs.builder()
            .authAppId(authAppId?.applyValue({ args0 -> args0 }))
            .dataPartitionNames(
                dataPartitionNames?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [EnergyServicePropertiesArgs].
 */
@PulumiTagMarker
public class EnergyServicePropertiesArgsBuilder internal constructor() {
    private var authAppId: Output<String>? = null

    private var dataPartitionNames: Output<List<DataPartitionNamesArgs>>? = null

    /**
     * @param value
     */
    @JvmName("opuknhqhgijgtmwq")
    public suspend fun authAppId(`value`: Output<String>) {
        this.authAppId = value
    }

    /**
     * @param value
     */
    @JvmName("ddjwdwucaojxvpmb")
    public suspend fun dataPartitionNames(`value`: Output<List<DataPartitionNamesArgs>>) {
        this.dataPartitionNames = value
    }

    @JvmName("cthvaoomhsojjcro")
    public suspend fun dataPartitionNames(vararg values: Output<DataPartitionNamesArgs>) {
        this.dataPartitionNames = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("jbdqendmpsjnijrm")
    public suspend fun dataPartitionNames(values: List<Output<DataPartitionNamesArgs>>) {
        this.dataPartitionNames = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("pgdfnmoippietucr")
    public suspend fun authAppId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authAppId = mapped
    }

    /**
     * @param value
     */
    @JvmName("gsrnijjmnkieyjwl")
    public suspend fun dataPartitionNames(`value`: List<DataPartitionNamesArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataPartitionNames = mapped
    }

    /**
     * @param argument
     */
    @JvmName("iyddtvodyqsxyves")
    public suspend
    fun dataPartitionNames(argument: List<suspend DataPartitionNamesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataPartitionNamesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataPartitionNames = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ljusyiuhovfnnbmw")
    public suspend fun dataPartitionNames(
        vararg
        argument: suspend DataPartitionNamesArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            DataPartitionNamesArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataPartitionNames = mapped
    }

    /**
     * @param argument
     */
    @JvmName("yclbbgogukxsotdy")
    public suspend
    fun dataPartitionNames(argument: suspend DataPartitionNamesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataPartitionNamesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dataPartitionNames = mapped
    }

    /**
     * @param values
     */
    @JvmName("lafbduaewspgnkao")
    public suspend fun dataPartitionNames(vararg values: DataPartitionNamesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataPartitionNames = mapped
    }

    internal fun build(): EnergyServicePropertiesArgs = EnergyServicePropertiesArgs(
        authAppId = authAppId,
        dataPartitionNames = dataPartitionNames,
    )
}
